import { getShare, getQrcode } from '../../api/base.js'
import { wxml, style } from './share.js'
const app = getApp()

Component({
  /**
   * 组件的属性列表
   */
  properties: {
    semesterId: { type: String, value: '' },
    courseId: { type: String, value: '' },
    chapterId: { type: String, value: '' },
    isNeed: { type: Boolean, value: false }
  },

  /**
   * 组件的初始数据
   */
  data: {
    show: false,
    hasControls: false,
    isPreivew: false,
    user: {},
    share: { lecturer: {} },
    qrcode: '',
    bgList: [
      'https://webapp-pub.ezijing.com/weapp/share/bg/01.jpg',
      'https://webapp-pub.ezijing.com/weapp/share/bg/02.jpg',
      'https://webapp-pub.ezijing.com/weapp/share/bg/03.jpg',
      'https://webapp-pub.ezijing.com/weapp/share/bg/04.jpg',
      'https://webapp-pub.ezijing.com/weapp/share/bg/05.jpg'
    ],
    textList: [
      '本质上，我们都生活在我们与内部体验或者外部事件的主观互动中。',
      '人本主义认为人是多维的，不能只去剖析本能，还要看思想和精神。',
      '别把身份全建立在与人的关系上，要寻找独立于关系之外的自我意识',
      '反思能力可得知自己的他人的不同,及自己的道德价值观和伦理模式'
    ],
    avatarList: [],
    controls: {
      active: '0',
      bg: 'https://webapp-pub.ezijing.com/weapp/share/bg/01.jpg',
      text: '本质上，我们都生活在我们与内部体验或者外部事件的主观互动中。',
      avatar: ''
    },
    wxUserProfile: {}
  },
  lifetimes: {
    attached() {
      // 获取微信头像
      const localUserInfo = wx.getStorageSync('userInfo')
      let wxUserProfile = localUserInfo ? JSON.parse(localUserInfo) : {}
      if (wxUserProfile.avatarUrl) {
        this.data.avatarList.push(wxUserProfile.avatarUrl)
        this.setData({ wxUserProfile, avatarList: this.data.avatarList, 'controls.avatar': wxUserProfile.avatarUrl })
      }
    }
  },
  /**
   * 组件的方法列表
   */
  methods: {
    init() {
      this.getShare().then(res => {
        // if (!this.data.isNeed && !res.data.need_share) {
        //   return
        // }
        app.getUser().then(res => {
          res.realname = res.realname || res.nickname
          if (res.avatar) {
            !this.data.avatarList.includes(res.avatar) && this.data.avatarList.unshift(res.avatar)
            this.setData({ avatarList: this.data.avatarList, 'controls.avatar': res.avatar })
          }
          this.setData({ user: res, show: true })
          this.getQrcode()
        })
      })
    },
    // 获取营销数据
    getShare() {
      const params = {
        semester_id: this.data.semesterId,
        course_id: this.data.courseId,
        chapter_id: this.data.chapterId
      }
      return getShare(params).then(res => {
        const data = res.data
        const [lecturer = { lecturer_name: '' }] = data.lecturers
        lecturer.lecturer_name = lecturer.lecturer_name ? lecturer.lecturer_name.replace(/(\(|（)(.+)(\)|）)/, '') : ''
        data.course_name = data.course_name ? data.course_name.replace(/(\(|（)(.+)(\)|）)/, '') : ''
        data.course_name = `《${data.course_name}》课程`
        data.chapter_name = data.chapter_name ? data.chapter_name.replace(/(\(|（)(.+)(\)|）)/, '') : ''

        // 两门课单独判断
        if (data.course_name.includes('整合心理学与批判性思考')) {
          const textList = [
            '本质上，我们都生活在我们与内部体验或者外部事件的主观互动中。',
            '人本主义认为人是多维的，不能只去剖析本能，还要看思想和精神。'
          ]
          this.setData({ textList, 'controls.text': textList[0] })
        }
        if (data.course_name.includes('自我探究')) {
          const textList = [
            '别把身份全建立在与人的关系上，要寻找独立于关系之外的自我意识',
            '反思能力可得知自己的他人的不同,及自己的道德价值观和伦理模式'
          ]
          this.setData({ textList, 'controls.text': textList[0] })
        }

        this.setData({ share: Object.assign(data, { lecturer }) })
        return res
      })
    },
    // 生成二维码
    getQrcode() {
      const user = this.data.user
      const params = {
        url: `https://pages.ezijing.com/ciis/mobile-204001490929.html?channel_num=96091&user_id=${user.id}&user_name=${user.realname}`
      }
      getQrcode(params).then(res => {
        this.setData({ qrcode: res.url })
      })
    },
    getUserProfile() {
      // 获取微信头像
      wx.getUserProfile({ desc: '使用头像生成海报' })
        .then(res => {
          const userInfo = res.userInfo
          this.data.avatarList.push(userInfo.avatarUrl)
          this.setData({ wxUserProfile: userInfo, avatarList: this.data.avatarList })
          wx.setStorageSync('userInfo', JSON.stringify(userInfo))
        })
        .catch(() => {
          wx.showToast({ title: '获取微信头像失败', icon: 'none' })
        })
    },
    renderToCanvas() {
      wx.showLoading({ title: '海报生成中' })
      this.setData({ isPreivew: true }, () => {
        this.widget = this.selectComponent('.widget')
        setTimeout(() => {
          this.widget
            .renderToCanvas({ wxml: wxml(this.data), style })
            .then(res => {
              wx.hideLoading()
            })
            .catch(error => {
              console.log(error)
              wx.hideLoading()
              wx.showToast({ title: '海报生成失败', icon: 'none' })
            })
        }, 500)
      })
    },
    // 导出图片
    extraImage() {
      this.widget.canvasToTempFilePath().then(res => {
        wx.saveImageToPhotosAlbum({
          filePath: res.tempFilePath
        })
          .then(res => {
            wx.showToast({ title: '保存成功', icon: 'none' })
          })
          .catch(error => {
            wx.showToast({ title: '保存失败', icon: 'none' })
          })
      })
    },
    // 关闭分享
    onClose() {
      this.setData({ show: false })
    },
    // 背景|金句选项卡切换
    onTabChange(e) {
      const { index } = e.currentTarget.dataset
      this.setData({ 'controls.active': index })
    },
    // 选择背景
    onSelectImage(e) {
      const { item } = e.currentTarget.dataset
      this.setData({ 'controls.bg': item })
    },
    // 选择金句
    onSelectText(e) {
      const { item } = e.currentTarget.dataset
      this.setData({ 'controls.text': item })
    },
    // 选择头像
    onSelectAvatar(e) {
      const { item } = e.currentTarget.dataset
      this.setData({ 'controls.avatar': item })
    },
    // 控制栏显示隐藏
    toggleControls() {
      this.setData({ hasControls: !this.data.hasControls })
    },
    // 关闭预览
    onClosePreview() {
      this.setData({ isPreivew: false })
    }
  }
})
